@@ -576,7 +576,6 @@ sub no_diff {
       `cat $expected_output | sed $sed_args > /tmp/pt-test-outfile-trf`;
       $expected_output = "/tmp/pt-test-outfile-trf";
    }
-
    # Determine cmd type and run it.
    if ( ref $cmd eq 'CODE' ) {
       output($cmd, file => $tmp_file);
@@ -654,7 +653,7 @@ sub no_diff {
    if ( $res_file ne $tmp_file ) {
       unlink $res_file if -f $res_file;
    }
-
+   
    if ( $cmp_file ne $expected_output ) {
       unlink $cmp_file if -f $cmp_file;
    }
@@ -814,10 +813,11 @@ sub tables_used {
    while ( defined(my $chunk = <$fh>) ) {
       map {
          my $db_tbl = $_;
+         $db_tbl =~ s/^\d{4}-\d\d-\d\dT\d\d:\d\d:\d\d\.\d+Z?//;  # strip leading timestamp (MySQL 5.7+)
          $db_tbl =~ s/^\s*`?//;  # strip leading space and `
          $db_tbl =~ s/\s*`?$//;  # strip trailing space and `
          $db_tbl =~ s/`\.`/./;   # strip inner `.`
-         $tables{$db_tbl} = 1;
+         $tables{$db_tbl} = 1 if !($db_tbl =~ m/^\s*$/);
       }
       grep {
          m/(?:\w\.\w|`\.`)/  # only db.tbl, not just db
